autowisp.processing_steps.stack_to_master_flat module — AutoWISP documentation

# autowisp.processing_steps.stack_to_master_flat module

## Class Inheritance Diagram

Stack calibrated flat frames to a master flat.

autowisp.processing_steps.stack_to_master_flat.cleanup_interrupted(interrupted, configuration)

  Cleanup file system after partially creating stacked image(s).

autowisp.processing_steps.stack_to_master_flat.get_master_fnames(image_fname, configuration)

  Return the filenames of the high and low master flats to generate.

autowisp.processing_steps.stack_to_master_flat.main()

  Run the step from the command line.

autowisp.processing_steps.stack_to_master_flat.parse_command_line(*args)

  Return the parsed command line arguments.

autowisp.processing_steps.stack_to_master_flat.stack_to_master_flat(image_collection, start_status, configuration, mark_start, mark_end)

  Stack the given frames to produce single high and/or low master flat.